part of 'workHistory_bloc.dart';

abstract class WorkHistorytEvent extends Equatable {
  const WorkHistorytEvent();

  @override
  List<Object> get props => [];
}

class GetWorkHistories extends WorkHistorytEvent{
  final int profileId;
  final String token;
  const GetWorkHistories({required this.profileId, required this.token});


    @override
  List<Object> get props => [profileId, token];
}

class LoadWorkHistories extends WorkHistorytEvent{
    @override
  List<Object> get props => [];
}

class ShowAddWorkHistoryForm extends WorkHistorytEvent{

}
class ShowEditWorkHistoryForm extends WorkHistorytEvent{
  final WorkHistory workHistory;
  const ShowEditWorkHistoryForm({required this.workHistory});
    @override
  List<Object> get props => [workHistory];

}
class DeleteWorkHistory extends WorkHistorytEvent{
  final String token;
  final int profileId;
  final WorkHistory workHistory;
  const DeleteWorkHistory({required this.profileId, required this.token, required this.workHistory});
      @override
  List<Object> get props => [token, profileId,workHistory];
}

class UpdateWorkHistory extends WorkHistorytEvent{
  final WorkHistory workHistory;
  final WorkHistory oldWorkHistory;
  final String profileId;
  final String token;
  const UpdateWorkHistory({required this.oldWorkHistory, required this.profileId, required this.token, required this.workHistory});
  @override
  List<Object> get props => [profileId,token,workHistory,oldWorkHistory];
}

class AddWorkHostory extends WorkHistorytEvent{
  final WorkHistory workHistory;
  final bool isPrivate;
  final int profileId;
  final String token;
  const AddWorkHostory({required this.workHistory, required this.isPrivate, required this.profileId, required this.token});
      @override
  List<Object> get props => [workHistory,profileId,token,isPrivate];
}


